@@ -1,14 +1,18 @@
 use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 
-use crate::evaluation::{dynamic_returnable::DynamicReturnable, dynamic_string::DynamicString};
+use crate::{
+    evaluation::{dynamic_returnable::DynamicReturnable, dynamic_string::DynamicString},
+    event_logging::exposable_string::ExposableString,
+    interned_string::InternedString,
+};
 
 #[derive(Serialize, Deserialize, Clone, PartialEq, Debug)]
 #[serde(rename_all = "camelCase")]
 pub struct CMABConfig {
     pub salt: String,
     #[serde(rename = "targetAppIDs")]
-    pub target_app_ids: Option<Vec<String>>,
+    pub target_app_ids: Option<Vec<InternedString>>,
     pub default_value: DynamicReturnable,
     pub id_type: DynamicString,
     pub enabled: bool,
@@ -17,7 +21,7 @@ pub struct CMABConfig {
     pub higher_is_better: bool,
     pub groups: Vec<CMABGroup>,
     pub config: Option<HashMap<String, CMABGroupConfig>>,
-    pub targeting_gate_name: Option<String>,
+    pub targeting_gate_name: Option<InternedString>,
 }
 
 #[derive(Serialize, Deserialize, Clone, PartialEq, Debug)]
@@ -25,7 +29,7 @@ pub struct CMABConfig {
 pub struct CMABGroup {
     pub name: String,
     pub parameter_values: DynamicReturnable,
-    pub id: String,
+    pub id: ExposableString,
 }
 
 #[derive(Serialize, Deserialize, Clone, PartialEq, Debug)]
